@@ -11,7 +11,7 @@ Returns the formatted string for testing purposes.
     use Log::Fine::Handle::String;
 
     # Get a new logger
-    my $log = Log::Fine->logger("foo");
+    my $log = Log::Fine->getLogger("foo");
 
     # register a file handle
     my $handle = Log::Fine::Handle::String->new();
@@ -35,35 +35,11 @@ use base qw( Log::Fine::Handle );
 
 =head1 METHODS
 
-=head2 msgWrite
+=head2 msgWrite($lvl, $msg, $skip)
 
-Returns the formatted message
+See L<Log::Fine::Handle>
 
-B<Note:> msgWrite() is an I<internal> method to the Log::Fine
-framework, meant to be sub-classed.  Use
-L<Log::Fine::Logger/log> for actual logging.
-
-=head3 Parameters
-
-=over
-
-=item  * level
-
-Level at which to log
-
-=item  * message
-
-Message to log
-
-=item  * skip
-
-Passed to L<caller|perlfunc/caller> for accurate method logging
-
-=back
-
-=head3 Returns
-
-The formatted message
+Returns the formatted message rather than the object.
 
 =cut
 
@@ -81,7 +57,7 @@ sub msgWrite
         # if we have a formatter defined, then use that, otherwise, just
         # print the raw message
         $msg = $self->{formatter}->format($lvl, $msg, $skip)
-            if defined $self->{formatter};
+                if defined $self->{formatter};
 
         # Victory!
         return $msg;
@@ -134,11 +110,11 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: b9c559f2170532f6eb986d8d803ffef0f47471b8 $
+  $Id: String.pm 35 2008-05-21 14:26:37Z cfuhrman $
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2008, 2010 Christopher M. Fuhrman, 
+Copyright (c) 2008 Christopher M. Fuhrman, 
 All rights reserved.
 
 This program is free software licensed under the...
